diff --git a/Marlin/Conditionals_post.h b/Marlin/Conditionals_post.h
index 2614217bbe1a01436ddc2bced4e8d2cf235b96f3..8c530395a01f1b396413858ceac11aed133a2e02 100644
--- a/Marlin/Conditionals_post.h
+++ b/Marlin/Conditionals_post.h
@@ -602,10 +602,10 @@
         #define XY_PROBE_SPEED 4000
       #endif
     #endif
-    #if Z_PROBE_TRAVEL_HEIGHT > Z_PROBE_DEPLOY_HEIGHT
-      #define _Z_PROBE_DEPLOY_HEIGHT Z_PROBE_TRAVEL_HEIGHT
+    #if Z_RAISE_BETWEEN_PROBES > Z_RAISE_DEPLOY_PROBE
+      #define _Z_RAISE_DEPLOY_PROBE Z_RAISE_BETWEEN_PROBES
     #else
-      #define _Z_PROBE_DEPLOY_HEIGHT Z_PROBE_DEPLOY_HEIGHT
+      #define _Z_RAISE_DEPLOY_PROBE Z_RAISE_DEPLOY_PROBE
     #endif
   #else
     #undef X_PROBE_OFFSET_FROM_EXTRUDER
@@ -681,17 +681,17 @@
   #endif
 
   /**
-   * Z_HOMING_HEIGHT / Z_PROBE_TRAVEL_HEIGHT
+   * Z_HOMING_HEIGHT / Z_RAISE_BETWEEN_PROBES
    */
   #ifndef Z_HOMING_HEIGHT
-    #ifndef Z_PROBE_TRAVEL_HEIGHT
+    #ifndef Z_RAISE_BETWEEN_PROBES
       #define Z_HOMING_HEIGHT 0
     #else
-      #define Z_HOMING_HEIGHT Z_PROBE_TRAVEL_HEIGHT
+      #define Z_HOMING_HEIGHT Z_RAISE_BETWEEN_PROBES
     #endif
   #endif
-  #ifndef Z_PROBE_TRAVEL_HEIGHT
-    #define Z_PROBE_TRAVEL_HEIGHT Z_HOMING_HEIGHT
+  #ifndef Z_RAISE_BETWEEN_PROBES
+    #define Z_RAISE_BETWEEN_PROBES Z_HOMING_HEIGHT
   #endif
 
   #if IS_KINEMATIC
diff --git a/Marlin/Configuration.h b/Marlin/Configuration.h
index 0361d8eeaa0e5b10246787bcfe0f099801940f72..41774ae51e1ba7ecd6fef9ae21f58e105127beea 100644
--- a/Marlin/Configuration.h
+++ b/Marlin/Configuration.h
@@ -619,12 +619,22 @@
 // Enable Z Probe Repeatability test to see how accurate your probe is
 //#define Z_MIN_PROBE_REPEATABILITY_TEST
 
-//
-// Minimum heights for the probe to deploy/stow and travel.
-// These values specify the distance from the NOZZLE to the BED.
-//
-#define Z_PROBE_DEPLOY_HEIGHT 15 // Z position for the probe to deploy/stow
-#define Z_PROBE_TRAVEL_HEIGHT  5 // Z position for travel between points
+/**
+ * Z probes require clearance when deploying, stowing, and moving between
+ * probe points to avoid hitting the bed and other hardware.
+ * Servo-mounted probes require extra space for the arm to rotate.
+ * Inductive probes need space to keep from triggering early.
+ *
+ * Use these settings to specify the distance (mm) to raise the probe (or
+ * lower the bed). The values set here apply over and above any (negative)
+ * probe Z Offset set with Z_PROBE_OFFSET_FROM_EXTRUDER, M851, or the LCD.
+ * Only integer values >= 1 are valid here.
+ *
+ * Example: `M851 Z-5` with a RAISE of 4  =>  9mm from bed to nozzle.
+ *     But: `M851 Z+1` with a RAISE of 2  =>  2mm from bed to nozzle.
+ */
+#define Z_RAISE_DEPLOY_PROBE   10 // Z Raise for Deploy/Stow
+#define Z_RAISE_BETWEEN_PROBES  5 // Z Raise between probe points
 
 //
 // For M851 give a range for adjusting the Z probe offset
diff --git a/Marlin/SanityCheck.h b/Marlin/SanityCheck.h
index dccf7b8ea1c88df3b141ad049eb04cbbf3338392..497409fc739809e9d656ed6b013df768a959ac29 100644
--- a/Marlin/SanityCheck.h
+++ b/Marlin/SanityCheck.h
@@ -130,9 +130,11 @@
 #elif defined(MIN_Z_HEIGHT_FOR_HOMING)
   #error "MIN_Z_HEIGHT_FOR_HOMING is now Z_HOMING_HEIGHT. Please update your configuration."
 #elif defined(Z_RAISE_BEFORE_PROBING) || defined(Z_RAISE_AFTER_PROBING)
-  #error "Z_RAISE_(BEFORE|AFTER)_PROBING are deprecated. Use Z_PROBE_DEPLOY_HEIGHT instead."
+  #error "Z_RAISE_(BEFORE|AFTER)_PROBING are deprecated. Use Z_RAISE_DEPLOY_PROBE instead."
 #elif defined(Z_RAISE_PROBE_DEPLOY_STOW) || defined(Z_RAISE_BETWEEN_PROBINGS)
-  #error "Z_RAISE_PROBE_DEPLOY_STOW and Z_RAISE_BETWEEN_PROBINGS are now Z_PROBE_DEPLOY_HEIGHT and Z_PROBE_TRAVEL_HEIGHT Please update your configuration."
+  #error "Z_RAISE_PROBE_DEPLOY_STOW and Z_RAISE_BETWEEN_PROBINGS are now Z_RAISE_DEPLOY_PROBE and Z_RAISE_BETWEEN_PROBES. Please update your configuration."
+#elif defined(Z_PROBE_DEPLOY_HEIGHT) || defined(Z_PROBE_TRAVEL_HEIGHT)
+  #error "Z_PROBE_DEPLOY_HEIGHT and Z_PROBE_TRAVEL_HEIGHT are now Z_RAISE_DEPLOY_PROBE and Z_RAISE_BETWEEN_PROBES. Please update your configuration."
 #elif !defined(MIN_STEPS_PER_SEGMENT)
   #error Please replace "const int dropsegments" with "#define MIN_STEPS_PER_SEGMENT" (and increase by 1) in Configuration_adv.h.
 #elif defined(PREVENT_DANGEROUS_EXTRUDE)
@@ -425,14 +427,14 @@
   /**
    * Make sure Z raise values are set
    */
-  #if !defined(Z_PROBE_DEPLOY_HEIGHT)
-    #error "You must set Z_PROBE_DEPLOY_HEIGHT in your configuration."
-  #elif !defined(Z_PROBE_TRAVEL_HEIGHT)
-    #error "You must set Z_PROBE_TRAVEL_HEIGHT in your configuration."
-  #elif Z_PROBE_DEPLOY_HEIGHT < 0
-    #error "Probes need Z_PROBE_DEPLOY_HEIGHT >= 0."
-  #elif Z_PROBE_TRAVEL_HEIGHT < 0
-    #error "Probes need Z_PROBE_TRAVEL_HEIGHT >= 0."
+  #if !defined(Z_RAISE_DEPLOY_PROBE)
+    #error "You must define Z_RAISE_DEPLOY_PROBE in your configuration."
+  #elif !defined(Z_RAISE_BETWEEN_PROBES)
+    #error "You must define Z_RAISE_BETWEEN_PROBES in your configuration."
+  #elif Z_RAISE_DEPLOY_PROBE < 0
+    #error "Probes need Z_RAISE_DEPLOY_PROBE >= 0."
+  #elif Z_RAISE_BETWEEN_PROBES < 0
+    #error "Probes need Z_RAISE_BETWEEN_PROBES >= 0."
   #endif
 
 #else
diff --git a/Marlin/example_configurations/Cartesio/Configuration.h b/Marlin/example_configurations/Cartesio/Configuration.h
index da7161e3c9bfb20db388515dd8059d93bfc6a545..3966c2eb29fa554e868c7b7ede531864565db19b 100644
--- a/Marlin/example_configurations/Cartesio/Configuration.h
+++ b/Marlin/example_configurations/Cartesio/Configuration.h
@@ -602,12 +602,22 @@
 // Enable Z Probe Repeatability test to see how accurate your probe is
 //#define Z_MIN_PROBE_REPEATABILITY_TEST
 
-//
-// Minimum heights for the probe to deploy/stow and travel.
-// These values specify the distance from the NOZZLE to the BED.
-//
-#define Z_PROBE_DEPLOY_HEIGHT 15 // Z position for the probe to deploy/stow
-#define Z_PROBE_TRAVEL_HEIGHT  5 // Z position for travel between points
+/**
+ * Z probes require clearance when deploying, stowing, and moving between
+ * probe points to avoid hitting the bed and other hardware.
+ * Servo-mounted probes require extra space for the arm to rotate.
+ * Inductive probes need space to keep from triggering early.
+ *
+ * Use these settings to specify the distance (mm) to raise the probe (or
+ * lower the bed). The values set here apply over and above any (negative)
+ * probe Z Offset set with Z_PROBE_OFFSET_FROM_EXTRUDER, M851, or the LCD.
+ * Only integer values >= 1 are valid here.
+ *
+ * Example: `M851 Z-5` with a RAISE of 4  =>  9mm from bed to nozzle.
+ *     But: `M851 Z+1` with a RAISE of 2  =>  2mm from bed to nozzle.
+ */
+#define Z_RAISE_DEPLOY_PROBE   15 // Z Raise for Deploy/Stow
+#define Z_RAISE_BETWEEN_PROBES  5 // Z Raise between probe points
 
 //
 // For M851 give a range for adjusting the Z probe offset
diff --git a/Marlin/example_configurations/Felix/Configuration.h b/Marlin/example_configurations/Felix/Configuration.h
index 16802dfd32803af37d0734ee3f9cfc5e61c19a6a..cba4ee8c8180c27f9cd7f3d2041d9960d12c6885 100644
--- a/Marlin/example_configurations/Felix/Configuration.h
+++ b/Marlin/example_configurations/Felix/Configuration.h
@@ -585,12 +585,22 @@
 // Enable Z Probe Repeatability test to see how accurate your probe is
 //#define Z_MIN_PROBE_REPEATABILITY_TEST
 
-//
-// Minimum heights for the probe to deploy/stow and travel.
-// These values specify the distance from the NOZZLE to the BED.
-//
-#define Z_PROBE_DEPLOY_HEIGHT 15 // Z position for the probe to deploy/stow
-#define Z_PROBE_TRAVEL_HEIGHT  5 // Z position for travel between points
+/**
+ * Z probes require clearance when deploying, stowing, and moving between
+ * probe points to avoid hitting the bed and other hardware.
+ * Servo-mounted probes require extra space for the arm to rotate.
+ * Inductive probes need space to keep from triggering early.
+ *
+ * Use these settings to specify the distance (mm) to raise the probe (or
+ * lower the bed). The values set here apply over and above any (negative)
+ * probe Z Offset set with Z_PROBE_OFFSET_FROM_EXTRUDER, M851, or the LCD.
+ * Only integer values >= 1 are valid here.
+ *
+ * Example: `M851 Z-5` with a RAISE of 4  =>  9mm from bed to nozzle.
+ *     But: `M851 Z+1` with a RAISE of 2  =>  2mm from bed to nozzle.
+ */
+#define Z_RAISE_DEPLOY_PROBE   15 // Z Raise for Deploy/Stow
+#define Z_RAISE_BETWEEN_PROBES  5 // Z Raise between probe points
 
 //
 // For M851 give a range for adjusting the Z probe offset
diff --git a/Marlin/example_configurations/Felix/DUAL/Configuration.h b/Marlin/example_configurations/Felix/DUAL/Configuration.h
index b8baf3c6776e8bdd879e614f0786da0e856080f5..d17be9a9c1e39306e5b2a7fc3ff793aa522c8d5b 100644
--- a/Marlin/example_configurations/Felix/DUAL/Configuration.h
+++ b/Marlin/example_configurations/Felix/DUAL/Configuration.h
@@ -583,12 +583,22 @@
 // Enable Z Probe Repeatability test to see how accurate your probe is
 //#define Z_MIN_PROBE_REPEATABILITY_TEST
 
-//
-// Minimum heights for the probe to deploy/stow and travel.
-// These values specify the distance from the NOZZLE to the BED.
-//
-#define Z_PROBE_DEPLOY_HEIGHT 15 // Z position for the probe to deploy/stow
-#define Z_PROBE_TRAVEL_HEIGHT  5 // Z position for travel between points
+/**
+ * Z probes require clearance when deploying, stowing, and moving between
+ * probe points to avoid hitting the bed and other hardware.
+ * Servo-mounted probes require extra space for the arm to rotate.
+ * Inductive probes need space to keep from triggering early.
+ *
+ * Use these settings to specify the distance (mm) to raise the probe (or
+ * lower the bed). The values set here apply over and above any (negative)
+ * probe Z Offset set with Z_PROBE_OFFSET_FROM_EXTRUDER, M851, or the LCD.
+ * Only integer values >= 1 are valid here.
+ *
+ * Example: `M851 Z-5` with a RAISE of 4  =>  9mm from bed to nozzle.
+ *     But: `M851 Z+1` with a RAISE of 2  =>  2mm from bed to nozzle.
+ */
+#define Z_RAISE_DEPLOY_PROBE   15 // Z Raise for Deploy/Stow
+#define Z_RAISE_BETWEEN_PROBES  5 // Z Raise between probe points
 
 //
 // For M851 give a range for adjusting the Z probe offset
diff --git a/Marlin/example_configurations/Hephestos/Configuration.h b/Marlin/example_configurations/Hephestos/Configuration.h
index 5bac996bba6839fa9b61e9269ef9f3f6b2b20d42..425035e88637f9b2ac78799bf5fcdf0864341933 100644
--- a/Marlin/example_configurations/Hephestos/Configuration.h
+++ b/Marlin/example_configurations/Hephestos/Configuration.h
@@ -594,12 +594,22 @@
 // Enable Z Probe Repeatability test to see how accurate your probe is
 //#define Z_MIN_PROBE_REPEATABILITY_TEST
 
-//
-// Minimum heights for the probe to deploy/stow and travel.
-// These values specify the distance from the NOZZLE to the BED.
-//
-#define Z_PROBE_DEPLOY_HEIGHT 15 // Z position for the probe to deploy/stow
-#define Z_PROBE_TRAVEL_HEIGHT  5 // Z position for travel between points
+/**
+ * Z probes require clearance when deploying, stowing, and moving between
+ * probe points to avoid hitting the bed and other hardware.
+ * Servo-mounted probes require extra space for the arm to rotate.
+ * Inductive probes need space to keep from triggering early.
+ *
+ * Use these settings to specify the distance (mm) to raise the probe (or
+ * lower the bed). The values set here apply over and above any (negative)
+ * probe Z Offset set with Z_PROBE_OFFSET_FROM_EXTRUDER, M851, or the LCD.
+ * Only integer values >= 1 are valid here.
+ *
+ * Example: `M851 Z-5` with a RAISE of 4  =>  9mm from bed to nozzle.
+ *     But: `M851 Z+1` with a RAISE of 2  =>  2mm from bed to nozzle.
+ */
+#define Z_RAISE_DEPLOY_PROBE   15 // Z Raise for Deploy/Stow
+#define Z_RAISE_BETWEEN_PROBES  5 // Z Raise between probe points
 
 //
 // For M851 give a range for adjusting the Z probe offset
diff --git a/Marlin/example_configurations/Hephestos_2/Configuration.h b/Marlin/example_configurations/Hephestos_2/Configuration.h
index fc5a6cf92a7bba01b6781c2fda081ed5afa425bd..b62ecec2c9c435c6fe63ae63484fc67c2adcd25d 100644
--- a/Marlin/example_configurations/Hephestos_2/Configuration.h
+++ b/Marlin/example_configurations/Hephestos_2/Configuration.h
@@ -596,12 +596,22 @@
 // Enable Z Probe Repeatability test to see how accurate your probe is
 //#define Z_MIN_PROBE_REPEATABILITY_TEST
 
-//
-// Minimum heights for the probe to deploy/stow and travel.
-// These values specify the distance from the NOZZLE to the BED.
-//
-#define Z_PROBE_DEPLOY_HEIGHT  5 // Z position for the probe to deploy/stow
-#define Z_PROBE_TRAVEL_HEIGHT  2 // Z position for travel between points
+/**
+ * Z probes require clearance when deploying, stowing, and moving between
+ * probe points to avoid hitting the bed and other hardware.
+ * Servo-mounted probes require extra space for the arm to rotate.
+ * Inductive probes need space to keep from triggering early.
+ *
+ * Use these settings to specify the distance (mm) to raise the probe (or
+ * lower the bed). The values set here apply over and above any (negative)
+ * probe Z Offset set with Z_PROBE_OFFSET_FROM_EXTRUDER, M851, or the LCD.
+ * Only integer values >= 1 are valid here.
+ *
+ * Example: `M851 Z-5` with a RAISE of 4  =>  9mm from bed to nozzle.
+ *     But: `M851 Z+1` with a RAISE of 2  =>  2mm from bed to nozzle.
+ */
+#define Z_RAISE_DEPLOY_PROBE   5 // Z Raise for Deploy/Stow
+#define Z_RAISE_BETWEEN_PROBES 2 // Z Raise between probe points
 
 //
 // For M851 give a range for adjusting the Z probe offset
diff --git a/Marlin/example_configurations/K8200/Configuration.h b/Marlin/example_configurations/K8200/Configuration.h
index 87142b70b4454ecd0e847d827bcdc93df8e63324..f08613ac52c1a8a87bf160e2c3dba8a09fda8e63 100644
--- a/Marlin/example_configurations/K8200/Configuration.h
+++ b/Marlin/example_configurations/K8200/Configuration.h
@@ -619,12 +619,22 @@
 // Enable Z Probe Repeatability test to see how accurate your probe is
 //#define Z_MIN_PROBE_REPEATABILITY_TEST
 
-//
-// Minimum heights for the probe to deploy/stow and travel.
-// These values specify the distance from the NOZZLE to the BED.
-//
-#define Z_PROBE_DEPLOY_HEIGHT 15 // Z position for the probe to deploy/stow
-#define Z_PROBE_TRAVEL_HEIGHT  5 // Z position for travel between points
+/**
+ * Z probes require clearance when deploying, stowing, and moving between
+ * probe points to avoid hitting the bed and other hardware.
+ * Servo-mounted probes require extra space for the arm to rotate.
+ * Inductive probes need space to keep from triggering early.
+ *
+ * Use these settings to specify the distance (mm) to raise the probe (or
+ * lower the bed). The values set here apply over and above any (negative)
+ * probe Z Offset set with Z_PROBE_OFFSET_FROM_EXTRUDER, M851, or the LCD.
+ * Only integer values >= 1 are valid here.
+ *
+ * Example: `M851 Z-5` with a RAISE of 4  =>  9mm from bed to nozzle.
+ *     But: `M851 Z+1` with a RAISE of 2  =>  2mm from bed to nozzle.
+ */
+#define Z_RAISE_DEPLOY_PROBE   15 // Z Raise for Deploy/Stow
+#define Z_RAISE_BETWEEN_PROBES  5 // Z Raise between probe points
 
 //
 // For M851 give a range for adjusting the Z probe offset
diff --git a/Marlin/example_configurations/K8400/Configuration.h b/Marlin/example_configurations/K8400/Configuration.h
index e3c7b8433df75ab5d1be9152ac0224ee858fe19b..630fe90d6704c6557fbf68d6b88d6d3a951a6d0d 100644
--- a/Marlin/example_configurations/K8400/Configuration.h
+++ b/Marlin/example_configurations/K8400/Configuration.h
@@ -602,12 +602,22 @@
 // Enable Z Probe Repeatability test to see how accurate your probe is
 //#define Z_MIN_PROBE_REPEATABILITY_TEST
 
-//
-// Minimum heights for the probe to deploy/stow and travel.
-// These values specify the distance from the NOZZLE to the BED.
-//
-#define Z_PROBE_DEPLOY_HEIGHT 15 // Z position for the probe to deploy/stow
-#define Z_PROBE_TRAVEL_HEIGHT  5 // Z position for travel between points
+/**
+ * Z probes require clearance when deploying, stowing, and moving between
+ * probe points to avoid hitting the bed and other hardware.
+ * Servo-mounted probes require extra space for the arm to rotate.
+ * Inductive probes need space to keep from triggering early.
+ *
+ * Use these settings to specify the distance (mm) to raise the probe (or
+ * lower the bed). The values set here apply over and above any (negative)
+ * probe Z Offset set with Z_PROBE_OFFSET_FROM_EXTRUDER, M851, or the LCD.
+ * Only integer values >= 1 are valid here.
+ *
+ * Example: `M851 Z-5` with a RAISE of 4  =>  9mm from bed to nozzle.
+ *     But: `M851 Z+1` with a RAISE of 2  =>  2mm from bed to nozzle.
+ */
+#define Z_RAISE_DEPLOY_PROBE   15 // Z Raise for Deploy/Stow
+#define Z_RAISE_BETWEEN_PROBES  5 // Z Raise between probe points
 
 //
 // For M851 give a range for adjusting the Z probe offset
diff --git a/Marlin/example_configurations/K8400/Dual-head/Configuration.h b/Marlin/example_configurations/K8400/Dual-head/Configuration.h
index 27f58977d74e321fb9b5a3733f1f714c843b3e2b..5716bc2712cfa0ea3f43dcffb4c858d684b8bd10 100644
--- a/Marlin/example_configurations/K8400/Dual-head/Configuration.h
+++ b/Marlin/example_configurations/K8400/Dual-head/Configuration.h
@@ -602,12 +602,22 @@
 // Enable Z Probe Repeatability test to see how accurate your probe is
 //#define Z_MIN_PROBE_REPEATABILITY_TEST
 
-//
-// Minimum heights for the probe to deploy/stow and travel.
-// These values specify the distance from the NOZZLE to the BED.
-//
-#define Z_PROBE_DEPLOY_HEIGHT 15 // Z position for the probe to deploy/stow
-#define Z_PROBE_TRAVEL_HEIGHT  5 // Z position for travel between points
+/**
+ * Z probes require clearance when deploying, stowing, and moving between
+ * probe points to avoid hitting the bed and other hardware.
+ * Servo-mounted probes require extra space for the arm to rotate.
+ * Inductive probes need space to keep from triggering early.
+ *
+ * Use these settings to specify the distance (mm) to raise the probe (or
+ * lower the bed). The values set here apply over and above any (negative)
+ * probe Z Offset set with Z_PROBE_OFFSET_FROM_EXTRUDER, M851, or the LCD.
+ * Only integer values >= 1 are valid here.
+ *
+ * Example: `M851 Z-5` with a RAISE of 4  =>  9mm from bed to nozzle.
+ *     But: `M851 Z+1` with a RAISE of 2  =>  2mm from bed to nozzle.
+ */
+#define Z_RAISE_DEPLOY_PROBE   15 // Z Raise for Deploy/Stow
+#define Z_RAISE_BETWEEN_PROBES  5 // Z Raise between probe points
 
 //
 // For M851 give a range for adjusting the Z probe offset
diff --git a/Marlin/example_configurations/RepRapWorld/Megatronics/Configuration.h b/Marlin/example_configurations/RepRapWorld/Megatronics/Configuration.h
index 1755e47d3be1aaa9e16bd6ebd61334b14fcd464d..f6a5f449c49e74dd980e94df2cfd6dc6a467a57c 100644
--- a/Marlin/example_configurations/RepRapWorld/Megatronics/Configuration.h
+++ b/Marlin/example_configurations/RepRapWorld/Megatronics/Configuration.h
@@ -602,12 +602,22 @@
 // Enable Z Probe Repeatability test to see how accurate your probe is
 //#define Z_MIN_PROBE_REPEATABILITY_TEST
 
-//
-// Minimum heights for the probe to deploy/stow and travel.
-// These values specify the distance from the NOZZLE to the BED.
-//
-#define Z_PROBE_DEPLOY_HEIGHT 15 // Z position for the probe to deploy/stow
-#define Z_PROBE_TRAVEL_HEIGHT  5 // Z position for travel between points
+/**
+ * Z probes require clearance when deploying, stowing, and moving between
+ * probe points to avoid hitting the bed and other hardware.
+ * Servo-mounted probes require extra space for the arm to rotate.
+ * Inductive probes need space to keep from triggering early.
+ *
+ * Use these settings to specify the distance (mm) to raise the probe (or
+ * lower the bed). The values set here apply over and above any (negative)
+ * probe Z Offset set with Z_PROBE_OFFSET_FROM_EXTRUDER, M851, or the LCD.
+ * Only integer values >= 1 are valid here.
+ *
+ * Example: `M851 Z-5` with a RAISE of 4  =>  9mm from bed to nozzle.
+ *     But: `M851 Z+1` with a RAISE of 2  =>  2mm from bed to nozzle.
+ */
+#define Z_RAISE_DEPLOY_PROBE   15 // Z Raise for Deploy/Stow
+#define Z_RAISE_BETWEEN_PROBES  5 // Z Raise between probe points
 
 //
 // For M851 give a range for adjusting the Z probe offset
diff --git a/Marlin/example_configurations/RigidBot/Configuration.h b/Marlin/example_configurations/RigidBot/Configuration.h
index 1f4cd5747aa60cfabf7b09e8577086b00066e5f7..969736ab19caa1cebd22ace6f2a82e08e5d115c2 100644
--- a/Marlin/example_configurations/RigidBot/Configuration.h
+++ b/Marlin/example_configurations/RigidBot/Configuration.h
@@ -600,12 +600,22 @@
 // Enable Z Probe Repeatability test to see how accurate your probe is
 //#define Z_MIN_PROBE_REPEATABILITY_TEST
 
-//
-// Minimum heights for the probe to deploy/stow and travel.
-// These values specify the distance from the NOZZLE to the BED.
-//
-#define Z_PROBE_DEPLOY_HEIGHT 15 // Z position for the probe to deploy/stow
-#define Z_PROBE_TRAVEL_HEIGHT  5 // Z position for travel between points
+/**
+ * Z probes require clearance when deploying, stowing, and moving between
+ * probe points to avoid hitting the bed and other hardware.
+ * Servo-mounted probes require extra space for the arm to rotate.
+ * Inductive probes need space to keep from triggering early.
+ *
+ * Use these settings to specify the distance (mm) to raise the probe (or
+ * lower the bed). The values set here apply over and above any (negative)
+ * probe Z Offset set with Z_PROBE_OFFSET_FROM_EXTRUDER, M851, or the LCD.
+ * Only integer values >= 1 are valid here.
+ *
+ * Example: `M851 Z-5` with a RAISE of 4  =>  9mm from bed to nozzle.
+ *     But: `M851 Z+1` with a RAISE of 2  =>  2mm from bed to nozzle.
+ */
+#define Z_RAISE_DEPLOY_PROBE   15 // Z Raise for Deploy/Stow
+#define Z_RAISE_BETWEEN_PROBES  5 // Z Raise between probe points
 
 //
 // For M851 give a range for adjusting the Z probe offset
diff --git a/Marlin/example_configurations/SCARA/Configuration.h b/Marlin/example_configurations/SCARA/Configuration.h
index a0bc7066dc2a7ec4a9af93a13093e503191dd711..375b5140d37b702044f51187e851d71cb67889fc 100644
--- a/Marlin/example_configurations/SCARA/Configuration.h
+++ b/Marlin/example_configurations/SCARA/Configuration.h
@@ -612,12 +612,22 @@
 // Enable Z Probe Repeatability test to see how accurate your probe is
 //#define Z_MIN_PROBE_REPEATABILITY_TEST
 
-//
-// Minimum heights for the probe to deploy/stow and travel.
-// These values specify the distance from the NOZZLE to the BED.
-//
-#define Z_PROBE_DEPLOY_HEIGHT 15 // Z position for the probe to deploy/stow
-#define Z_PROBE_TRAVEL_HEIGHT  5 // Z position for travel between points
+/**
+ * Z probes require clearance when deploying, stowing, and moving between
+ * probe points to avoid hitting the bed and other hardware.
+ * Servo-mounted probes require extra space for the arm to rotate.
+ * Inductive probes need space to keep from triggering early.
+ *
+ * Use these settings to specify the distance (mm) to raise the probe (or
+ * lower the bed). The values set here apply over and above any (negative)
+ * probe Z Offset set with Z_PROBE_OFFSET_FROM_EXTRUDER, M851, or the LCD.
+ * Only integer values >= 1 are valid here.
+ *
+ * Example: `M851 Z-5` with a RAISE of 4  =>  9mm from bed to nozzle.
+ *     But: `M851 Z+1` with a RAISE of 2  =>  2mm from bed to nozzle.
+ */
+#define Z_RAISE_DEPLOY_PROBE   15 // Z Raise for Deploy/Stow
+#define Z_RAISE_BETWEEN_PROBES  5 // Z Raise between probe points
 
 //
 // For M851 give a range for adjusting the Z probe offset
diff --git a/Marlin/example_configurations/TAZ4/Configuration.h b/Marlin/example_configurations/TAZ4/Configuration.h
index 495e11bdf4adec0b0580089a9cb8a0d567b2d849..2c9f17bf949ee4c33791061c05b5663509159dfa 100644
--- a/Marlin/example_configurations/TAZ4/Configuration.h
+++ b/Marlin/example_configurations/TAZ4/Configuration.h
@@ -623,12 +623,22 @@
 // Enable Z Probe Repeatability test to see how accurate your probe is
 //#define Z_MIN_PROBE_REPEATABILITY_TEST
 
-//
-// Minimum heights for the probe to deploy/stow and travel.
-// These values specify the distance from the NOZZLE to the BED.
-//
-#define Z_PROBE_DEPLOY_HEIGHT 15 // Z position for the probe to deploy/stow
-#define Z_PROBE_TRAVEL_HEIGHT  5 // Z position for travel between points
+/**
+ * Z probes require clearance when deploying, stowing, and moving between
+ * probe points to avoid hitting the bed and other hardware.
+ * Servo-mounted probes require extra space for the arm to rotate.
+ * Inductive probes need space to keep from triggering early.
+ *
+ * Use these settings to specify the distance (mm) to raise the probe (or
+ * lower the bed). The values set here apply over and above any (negative)
+ * probe Z Offset set with Z_PROBE_OFFSET_FROM_EXTRUDER, M851, or the LCD.
+ * Only integer values >= 1 are valid here.
+ *
+ * Example: `M851 Z-5` with a RAISE of 4  =>  9mm from bed to nozzle.
+ *     But: `M851 Z+1` with a RAISE of 2  =>  2mm from bed to nozzle.
+ */
+#define Z_RAISE_DEPLOY_PROBE   15 // Z Raise for Deploy/Stow
+#define Z_RAISE_BETWEEN_PROBES  5 // Z Raise between probe points
 
 //
 // For M851 give a range for adjusting the Z probe offset
diff --git a/Marlin/example_configurations/WITBOX/Configuration.h b/Marlin/example_configurations/WITBOX/Configuration.h
index b46ce31480604ea0538ed972b79d06efc140a70d..7bd102ddcc6fca9add13994776684cea19d9476c 100644
--- a/Marlin/example_configurations/WITBOX/Configuration.h
+++ b/Marlin/example_configurations/WITBOX/Configuration.h
@@ -594,12 +594,22 @@
 // Enable Z Probe Repeatability test to see how accurate your probe is
 //#define Z_MIN_PROBE_REPEATABILITY_TEST
 
-//
-// Minimum heights for the probe to deploy/stow and travel.
-// These values specify the distance from the NOZZLE to the BED.
-//
-#define Z_PROBE_DEPLOY_HEIGHT 15 // Z position for the probe to deploy/stow
-#define Z_PROBE_TRAVEL_HEIGHT  5 // Z position for travel between points
+/**
+ * Z probes require clearance when deploying, stowing, and moving between
+ * probe points to avoid hitting the bed and other hardware.
+ * Servo-mounted probes require extra space for the arm to rotate.
+ * Inductive probes need space to keep from triggering early.
+ *
+ * Use these settings to specify the distance (mm) to raise the probe (or
+ * lower the bed). The values set here apply over and above any (negative)
+ * probe Z Offset set with Z_PROBE_OFFSET_FROM_EXTRUDER, M851, or the LCD.
+ * Only integer values >= 1 are valid here.
+ *
+ * Example: `M851 Z-5` with a RAISE of 4  =>  9mm from bed to nozzle.
+ *     But: `M851 Z+1` with a RAISE of 2  =>  2mm from bed to nozzle.
+ */
+#define Z_RAISE_DEPLOY_PROBE   15 // Z Raise for Deploy/Stow
+#define Z_RAISE_BETWEEN_PROBES  5 // Z Raise between probe points
 
 //
 // For M851 give a range for adjusting the Z probe offset
diff --git a/Marlin/example_configurations/adafruit/ST7565/Configuration.h b/Marlin/example_configurations/adafruit/ST7565/Configuration.h
index fd239237e1d226972ecad710a2b008f9ef358e38..9e504e4cacbd9971bca8260c574c147e695d4068 100644
--- a/Marlin/example_configurations/adafruit/ST7565/Configuration.h
+++ b/Marlin/example_configurations/adafruit/ST7565/Configuration.h
@@ -602,12 +602,22 @@
 // Enable Z Probe Repeatability test to see how accurate your probe is
 //#define Z_MIN_PROBE_REPEATABILITY_TEST
 
-//
-// Minimum heights for the probe to deploy/stow and travel.
-// These values specify the distance from the NOZZLE to the BED.
-//
-#define Z_PROBE_DEPLOY_HEIGHT 15 // Z position for the probe to deploy/stow
-#define Z_PROBE_TRAVEL_HEIGHT  5 // Z position for travel between points
+/**
+ * Z probes require clearance when deploying, stowing, and moving between
+ * probe points to avoid hitting the bed and other hardware.
+ * Servo-mounted probes require extra space for the arm to rotate.
+ * Inductive probes need space to keep from triggering early.
+ *
+ * Use these settings to specify the distance (mm) to raise the probe (or
+ * lower the bed). The values set here apply over and above any (negative)
+ * probe Z Offset set with Z_PROBE_OFFSET_FROM_EXTRUDER, M851, or the LCD.
+ * Only integer values >= 1 are valid here.
+ *
+ * Example: `M851 Z-5` with a RAISE of 4  =>  9mm from bed to nozzle.
+ *     But: `M851 Z+1` with a RAISE of 2  =>  2mm from bed to nozzle.
+ */
+#define Z_RAISE_DEPLOY_PROBE   15 // Z Raise for Deploy/Stow
+#define Z_RAISE_BETWEEN_PROBES  5 // Z Raise between probe points
 
 //
 // For M851 give a range for adjusting the Z probe offset
diff --git a/Marlin/example_configurations/delta/biv2.5/Configuration.h b/Marlin/example_configurations/delta/biv2.5/Configuration.h
index cbbe08b118d920c6b80246314fd7ca78e7a0f59b..38d9c9b11a173f893ed1238924ef0226ce4631bd 100644
--- a/Marlin/example_configurations/delta/biv2.5/Configuration.h
+++ b/Marlin/example_configurations/delta/biv2.5/Configuration.h
@@ -692,12 +692,22 @@
 // Enable Z Probe Repeatability test to see how accurate your probe is
 //#define Z_MIN_PROBE_REPEATABILITY_TEST
 
-//
-// Minimum heights for the probe to deploy/stow and travel.
-// These values specify the distance from the NOZZLE to the BED.
-//
-#define Z_PROBE_DEPLOY_HEIGHT 50 // Z position for the probe to deploy/stow
-#define Z_PROBE_TRAVEL_HEIGHT  5 // Z position for travel between points
+/**
+ * Z probes require clearance when deploying, stowing, and moving between
+ * probe points to avoid hitting the bed and other hardware.
+ * Servo-mounted probes require extra space for the arm to rotate.
+ * Inductive probes need space to keep from triggering early.
+ *
+ * Use these settings to specify the distance (mm) to raise the probe (or
+ * lower the bed). The values set here apply over and above any (negative)
+ * probe Z Offset set with Z_PROBE_OFFSET_FROM_EXTRUDER, M851, or the LCD.
+ * Only integer values >= 1 are valid here.
+ *
+ * Example: `M851 Z-5` with a RAISE of 4  =>  9mm from bed to nozzle.
+ *     But: `M851 Z+1` with a RAISE of 2  =>  2mm from bed to nozzle.
+ */
+#define Z_RAISE_DEPLOY_PROBE   50 // Z Raise for Deploy/Stow
+#define Z_RAISE_BETWEEN_PROBES  5 // Z Raise between probe points
 
 //
 // For M851 give a range for adjusting the Z probe offset
diff --git a/Marlin/example_configurations/delta/generic/Configuration.h b/Marlin/example_configurations/delta/generic/Configuration.h
index f609017fede1a509d09425035c73c28539938228..707375d3afb8160ead1de864108c9d29ba4c240a 100644
--- a/Marlin/example_configurations/delta/generic/Configuration.h
+++ b/Marlin/example_configurations/delta/generic/Configuration.h
@@ -686,12 +686,22 @@
 // Enable Z Probe Repeatability test to see how accurate your probe is
 //#define Z_MIN_PROBE_REPEATABILITY_TEST
 
-//
-// Minimum heights for the probe to deploy/stow and travel.
-// These values specify the distance from the NOZZLE to the BED.
-//
-#define Z_PROBE_DEPLOY_HEIGHT 15 // Z position for the probe to deploy/stow
-#define Z_PROBE_TRAVEL_HEIGHT  5 // Z position for travel between points
+/**
+ * Z probes require clearance when deploying, stowing, and moving between
+ * probe points to avoid hitting the bed and other hardware.
+ * Servo-mounted probes require extra space for the arm to rotate.
+ * Inductive probes need space to keep from triggering early.
+ *
+ * Use these settings to specify the distance (mm) to raise the probe (or
+ * lower the bed). The values set here apply over and above any (negative)
+ * probe Z Offset set with Z_PROBE_OFFSET_FROM_EXTRUDER, M851, or the LCD.
+ * Only integer values >= 1 are valid here.
+ *
+ * Example: `M851 Z-5` with a RAISE of 4  =>  9mm from bed to nozzle.
+ *     But: `M851 Z+1` with a RAISE of 2  =>  2mm from bed to nozzle.
+ */
+#define Z_RAISE_DEPLOY_PROBE   15 // Z Raise for Deploy/Stow
+#define Z_RAISE_BETWEEN_PROBES  5 // Z Raise between probe points
 
 //
 // For M851 give a range for adjusting the Z probe offset
diff --git a/Marlin/example_configurations/delta/kossel_mini/Configuration.h b/Marlin/example_configurations/delta/kossel_mini/Configuration.h
index 7bed412b19b692bf5f8e25b1952355f19fc9d267..b447e5379efc7676f7f10c5c092e5803050a882a 100644
--- a/Marlin/example_configurations/delta/kossel_mini/Configuration.h
+++ b/Marlin/example_configurations/delta/kossel_mini/Configuration.h
@@ -689,12 +689,22 @@
 // Enable Z Probe Repeatability test to see how accurate your probe is
 //#define Z_MIN_PROBE_REPEATABILITY_TEST
 
-//
-// Minimum heights for the probe to deploy/stow and travel.
-// These values specify the distance from the NOZZLE to the BED.
-//
-#define Z_PROBE_DEPLOY_HEIGHT 50 // Z position for the probe to deploy/stow
-#define Z_PROBE_TRAVEL_HEIGHT  5 // Z position for travel between points
+/**
+ * Z probes require clearance when deploying, stowing, and moving between
+ * probe points to avoid hitting the bed and other hardware.
+ * Servo-mounted probes require extra space for the arm to rotate.
+ * Inductive probes need space to keep from triggering early.
+ *
+ * Use these settings to specify the distance (mm) to raise the probe (or
+ * lower the bed). The values set here apply over and above any (negative)
+ * probe Z Offset set with Z_PROBE_OFFSET_FROM_EXTRUDER, M851, or the LCD.
+ * Only integer values >= 1 are valid here.
+ *
+ * Example: `M851 Z-5` with a RAISE of 4  =>  9mm from bed to nozzle.
+ *     But: `M851 Z+1` with a RAISE of 2  =>  2mm from bed to nozzle.
+ */
+#define Z_RAISE_DEPLOY_PROBE   50 // Z Raise for Deploy/Stow
+#define Z_RAISE_BETWEEN_PROBES  5 // Z Raise between probe points
 
 //
 // For M851 give a range for adjusting the Z probe offset
diff --git a/Marlin/example_configurations/delta/kossel_pro/Configuration.h b/Marlin/example_configurations/delta/kossel_pro/Configuration.h
index 264077dcf49d0a89d63784f6e1f827576407a110..fd3edb4617dce0731629d16a5c2e9b45eeca5126 100644
--- a/Marlin/example_configurations/delta/kossel_pro/Configuration.h
+++ b/Marlin/example_configurations/delta/kossel_pro/Configuration.h
@@ -690,12 +690,22 @@
 // Enable Z Probe Repeatability test to see how accurate your probe is
 //#define Z_MIN_PROBE_REPEATABILITY_TEST
 
-//
-// Minimum heights for the probe to deploy/stow and travel.
-// These values specify the distance from the NOZZLE to the BED.
-//
-#define Z_PROBE_DEPLOY_HEIGHT 100 // Z position for the probe to deploy/stow
-#define Z_PROBE_TRAVEL_HEIGHT   5 // Z position for travel between points
+/**
+ * Z probes require clearance when deploying, stowing, and moving between
+ * probe points to avoid hitting the bed and other hardware.
+ * Servo-mounted probes require extra space for the arm to rotate.
+ * Inductive probes need space to keep from triggering early.
+ *
+ * Use these settings to specify the distance (mm) to raise the probe (or
+ * lower the bed). The values set here apply over and above any (negative)
+ * probe Z Offset set with Z_PROBE_OFFSET_FROM_EXTRUDER, M851, or the LCD.
+ * Only integer values >= 1 are valid here.
+ *
+ * Example: `M851 Z-5` with a RAISE of 4  =>  9mm from bed to nozzle.
+ *     But: `M851 Z+1` with a RAISE of 2  =>  2mm from bed to nozzle.
+ */
+#define Z_RAISE_DEPLOY_PROBE   100 // Z Raise for Deploy/Stow
+#define Z_RAISE_BETWEEN_PROBES   5 // Z Raise between probe points
 
 //
 // For M851 give a range for adjusting the Z probe offset
diff --git a/Marlin/example_configurations/delta/kossel_xl/Configuration.h b/Marlin/example_configurations/delta/kossel_xl/Configuration.h
index eddc9fbb4e080efd885fbffe32de6fa64f623a6e..a5fd2c18a66df7ab3df19e5cb41a801c5c05c151 100644
--- a/Marlin/example_configurations/delta/kossel_xl/Configuration.h
+++ b/Marlin/example_configurations/delta/kossel_xl/Configuration.h
@@ -692,12 +692,22 @@
 // Enable Z Probe Repeatability test to see how accurate your probe is
 //#define Z_MIN_PROBE_REPEATABILITY_TEST
 
-//
-// Minimum heights for the probe to deploy/stow and travel.
-// These values specify the distance from the NOZZLE to the BED.
-//
-#define Z_PROBE_DEPLOY_HEIGHT 20 // Z position for the probe to deploy/stow
-#define Z_PROBE_TRAVEL_HEIGHT 10 // Z position for travel between points
+/**
+ * Z probes require clearance when deploying, stowing, and moving between
+ * probe points to avoid hitting the bed and other hardware.
+ * Servo-mounted probes require extra space for the arm to rotate.
+ * Inductive probes need space to keep from triggering early.
+ *
+ * Use these settings to specify the distance (mm) to raise the probe (or
+ * lower the bed). The values set here apply over and above any (negative)
+ * probe Z Offset set with Z_PROBE_OFFSET_FROM_EXTRUDER, M851, or the LCD.
+ * Only integer values >= 1 are valid here.
+ *
+ * Example: `M851 Z-5` with a RAISE of 4  =>  9mm from bed to nozzle.
+ *     But: `M851 Z+1` with a RAISE of 2  =>  2mm from bed to nozzle.
+ */
+#define Z_RAISE_DEPLOY_PROBE   20 // Z Raise for Deploy/Stow
+#define Z_RAISE_BETWEEN_PROBES 10 // Z Raise between probe points
 
 //
 // For M851 give a range for adjusting the Z probe offset
diff --git a/Marlin/example_configurations/makibox/Configuration.h b/Marlin/example_configurations/makibox/Configuration.h
index 9a76b77a8c8ca34d09abbad8266ea0d59ecd348f..b9a5dc30697b91eae268e93d80b9be249dcfa873 100644
--- a/Marlin/example_configurations/makibox/Configuration.h
+++ b/Marlin/example_configurations/makibox/Configuration.h
@@ -605,12 +605,22 @@
 // Enable Z Probe Repeatability test to see how accurate your probe is
 //#define Z_MIN_PROBE_REPEATABILITY_TEST
 
-//
-// Minimum heights for the probe to deploy/stow and travel.
-// These values specify the distance from the NOZZLE to the BED.
-//
-#define Z_PROBE_DEPLOY_HEIGHT 15 // Z position for the probe to deploy/stow
-#define Z_PROBE_TRAVEL_HEIGHT  5 // Z position for travel between points
+/**
+ * Z probes require clearance when deploying, stowing, and moving between
+ * probe points to avoid hitting the bed and other hardware.
+ * Servo-mounted probes require extra space for the arm to rotate.
+ * Inductive probes need space to keep from triggering early.
+ *
+ * Use these settings to specify the distance (mm) to raise the probe (or
+ * lower the bed). The values set here apply over and above any (negative)
+ * probe Z Offset set with Z_PROBE_OFFSET_FROM_EXTRUDER, M851, or the LCD.
+ * Only integer values >= 1 are valid here.
+ *
+ * Example: `M851 Z-5` with a RAISE of 4  =>  9mm from bed to nozzle.
+ *     But: `M851 Z+1` with a RAISE of 2  =>  2mm from bed to nozzle.
+ */
+#define Z_RAISE_DEPLOY_PROBE   15 // Z Raise for Deploy/Stow
+#define Z_RAISE_BETWEEN_PROBES  5 // Z Raise between probe points
 
 //
 // For M851 give a range for adjusting the Z probe offset
diff --git a/Marlin/example_configurations/tvrrug/Round2/Configuration.h b/Marlin/example_configurations/tvrrug/Round2/Configuration.h
index 40c317a52642f85a0f579de7a71ada2a37f1945b..5b70e2d897a14bdcbbec3f8d2191dce43f426dc1 100644
--- a/Marlin/example_configurations/tvrrug/Round2/Configuration.h
+++ b/Marlin/example_configurations/tvrrug/Round2/Configuration.h
@@ -598,12 +598,22 @@
 // Enable Z Probe Repeatability test to see how accurate your probe is
 //#define Z_MIN_PROBE_REPEATABILITY_TEST
 
-//
-// Minimum heights for the probe to deploy/stow and travel.
-// These values specify the distance from the NOZZLE to the BED.
-//
-#define Z_PROBE_DEPLOY_HEIGHT 15 // Z position for the probe to deploy/stow
-#define Z_PROBE_TRAVEL_HEIGHT  5 // Z position for travel between points
+/**
+ * Z probes require clearance when deploying, stowing, and moving between
+ * probe points to avoid hitting the bed and other hardware.
+ * Servo-mounted probes require extra space for the arm to rotate.
+ * Inductive probes need space to keep from triggering early.
+ *
+ * Use these settings to specify the distance (mm) to raise the probe (or
+ * lower the bed). The values set here apply over and above any (negative)
+ * probe Z Offset set with Z_PROBE_OFFSET_FROM_EXTRUDER, M851, or the LCD.
+ * Only integer values >= 1 are valid here.
+ *
+ * Example: `M851 Z-5` with a RAISE of 4  =>  9mm from bed to nozzle.
+ *     But: `M851 Z+1` with a RAISE of 2  =>  2mm from bed to nozzle.
+ */
+#define Z_RAISE_DEPLOY_PROBE   15 // Z Raise for Deploy/Stow
+#define Z_RAISE_BETWEEN_PROBES  5 // Z Raise between probe points
 
 //
 // For M851 give a range for adjusting the Z probe offset
diff --git a/Marlin/Marlin_main.cpp b/Marlin/Marlin_main.cpp
index 63dfcf76b4218d9a311b6a07fc4f1a76c3b7fd1e..b058e7bb7202407678a093526bbaa342efd80aab 100644
--- a/Marlin/Marlin_main.cpp
+++ b/Marlin/Marlin_main.cpp
@@ -1631,7 +1631,10 @@ static void clean_up_after_endstop_or_probe_move() {
         SERIAL_ECHOLNPGM(")");
       }
     #endif
+
     float z_dest = LOGICAL_Z_POSITION(z_raise);
+    if (zprobe_zoffset < 0) z_dest -= zprobe_zoffset;
+
     if (z_dest > current_position[Z_AXIS])
       do_blocking_move_to_z(z_dest);
   }
@@ -1879,7 +1882,7 @@ static void clean_up_after_endstop_or_probe_move() {
     if (endstops.z_probe_enabled == deploy) return false;
 
     // Make room for probe
-    do_probe_raise(_Z_PROBE_DEPLOY_HEIGHT);
+    do_probe_raise(_Z_RAISE_DEPLOY_PROBE);
 
     // Check BLTOUCH probe status for an error
     #if ENABLED(BLTOUCH)
@@ -1988,7 +1991,7 @@ static void clean_up_after_endstop_or_probe_move() {
 
       // If the nozzle is above the travel height then
       // move down quickly before doing the slow probe
-      float z = LOGICAL_Z_POSITION(Z_PROBE_TRAVEL_HEIGHT);
+      float z = LOGICAL_Z_POSITION(Z_RAISE_BETWEEN_PROBES);
       if (z < current_position[Z_AXIS])
         do_blocking_move_to_z(z, MMM_TO_MMS(Z_PROBE_SPEED_FAST));
 
@@ -2027,7 +2030,7 @@ static void clean_up_after_endstop_or_probe_move() {
     float old_feedrate_mm_s = feedrate_mm_s;
 
     // Ensure a minimum height before moving the probe
-    do_probe_raise(Z_PROBE_TRAVEL_HEIGHT);
+    do_probe_raise(Z_RAISE_BETWEEN_PROBES);
 
     // Move to the XY where we shall probe
     #if ENABLED(DEBUG_LEVELING_FEATURE)
@@ -2047,15 +2050,10 @@ static void clean_up_after_endstop_or_probe_move() {
 
     float measured_z = run_z_probe();
 
-    if (stow) {
+    if (!stow)
+      do_probe_raise(Z_RAISE_BETWEEN_PROBES);
+    else
       if (STOW_PROBE()) return NAN;
-    }
-    else {
-      #if ENABLED(DEBUG_LEVELING_FEATURE)
-        if (DEBUGGING(LEVELING)) SERIAL_ECHOLNPGM("> do_probe_raise");
-      #endif
-      do_probe_raise(Z_PROBE_TRAVEL_HEIGHT);
-    }
 
     if (verbose_level > 2) {
       SERIAL_PROTOCOLPGM("Bed X: ");
@@ -3099,8 +3097,8 @@ inline void gcode_G28() {
     feedrate_mm_s = homing_feedrate_mm_s[X_AXIS];
 
     current_position[Z_AXIS] = MESH_HOME_SEARCH_Z
-      #if Z_PROBE_TRAVEL_HEIGHT > Z_HOMING_HEIGHT
-        + Z_PROBE_TRAVEL_HEIGHT
+      #if Z_RAISE_BETWEEN_PROBES > Z_HOMING_HEIGHT
+        + Z_RAISE_BETWEEN_PROBES
       #elif Z_HOMING_HEIGHT > 0
         + Z_HOMING_HEIGHT
       #endif
@@ -3111,7 +3109,7 @@ inline void gcode_G28() {
     current_position[Y_AXIS] = LOGICAL_Y_POSITION(y);
     line_to_current_position();
 
-    #if Z_PROBE_TRAVEL_HEIGHT > 0 || Z_HOMING_HEIGHT > 0
+    #if Z_RAISE_BETWEEN_PROBES > 0 || Z_HOMING_HEIGHT > 0
       current_position[Z_AXIS] = LOGICAL_Z_POSITION(MESH_HOME_SEARCH_Z);
       line_to_current_position();
     #endif
@@ -3206,8 +3204,8 @@ inline void gcode_G28() {
         else {
           // One last "return to the bed" (as originally coded) at completion
           current_position[Z_AXIS] = MESH_HOME_SEARCH_Z
-            #if Z_PROBE_TRAVEL_HEIGHT > Z_HOMING_HEIGHT
-              + Z_PROBE_TRAVEL_HEIGHT
+            #if Z_RAISE_BETWEEN_PROBES > Z_HOMING_HEIGHT
+              + Z_RAISE_BETWEEN_PROBES
             #elif Z_HOMING_HEIGHT > 0
               + Z_HOMING_HEIGHT
             #endif
@@ -3560,7 +3558,7 @@ inline void gcode_G28() {
 
     #endif // AUTO_BED_LEVELING_3POINT
 
     // Raise to _Z_PROBE_DEPLOY_HEIGHT. Stow the probe.
     if (STOW_PROBE()) return;
 
     // Restore state after probing
@@ -3560,7 +3558,7 @@ inline void gcode_G28() {
     #endif // AUTO_BED_LEVELING_3POINT
 
-    // Raise to _Z_PROBE_DEPLOY_HEIGHT. Stow the probe.
+    // Raise to _Z_RAISE_DEPLOY_PROBE. Stow the probe.
     if (STOW_PROBE()) return;
 